StempCens
The functions provided are:
- CovarianceM: computes the spatio-temporal covariance matrix for balanced data.
- EffectiveRange: computes the effective range for an isotropic spatial correlation function.
- EstStempCens: returns the maximum likelihood estimates of the unknown parameters.
- PredStempCens: performs spatio-temporal prediction in a set of new S spatial locations for fixed time points.
- CrossStempCens: performs cross-validation, which measure the performance of the predictive model on new test dataset.
- DiagStempCens: returns measures and graphics for diagnostic analysis.
cook1977detectionStempCens
delyon1999convergenceStempCens
louis1982findingStempCens
zhu2001caseStempCens